OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contatos",
    "No contacts in here" : "Nenhum contato aqui",
    "Name" : "Nome",
    "Organization" : "Organização",
    "Title" : "Título ",
    "Add field ..." : "Adicionar campo ...",
    "Add contact" : "Adicionar contacto",
    "All contacts" : "Todos os contatos",
    "Not grouped" : "Não agrupados",
    "Post Office Box" : "Caixa Postal",
    "Postal Code" : "Código Postal",
    "City" : "Cidade",
    "State or province" : "Distrito",
    "Country" : "País",
    "Address" : "Endereço",
    "(new group)" : "(novo grupo)",
    "{addressbook} shared by {owner}" : "{addressbook} partilhado por {owner}",
    "Nickname" : "Alcunha",
    "Notes" : "Notas",
    "Website" : "Site da Internet",
    "Federated Cloud ID" : "Id. da Nuvem Federada",
    "Home" : "Início",
    "Work" : "Emprego",
    "Other" : "Outro",
    "Groups" : "Grupos",
    "Birthday" : "Aniversário",
    "Email" : "Correio Electrónico",
    "Instant messaging" : "Mensagens Instantâneas",
    "Phone" : "Telefone",
    "Mobile" : "Telemóvel",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do emprego",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Settings" : "Definições",
    "Import" : "Importar"
},
"nplurals=2; plural=(n != 1);");
